@@ -20,9 +20,10 @@
 package org.glom.web.client;
 
 import org.glom.web.client.ui.AuthenticationPopup;
-import org.glom.web.client.ui.DetailsView;
 import org.glom.web.client.ui.DocumentSelectionView;
+import org.glom.web.client.ui.DetailsView;
 import org.glom.web.client.ui.ListView;
+import org.glom.web.client.ui.ReportView;
 import org.glom.web.client.ui.TableSelectionView;
 
 import com.google.gwt.place.shared.PlaceController;
@@ -53,4 +54,6 @@ public interface ClientFactory {
 
 	DetailsView getDetailsView();
 
+	ReportView getReportView();
+
 }
